# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import image_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2
from yandex.cloud.containerregistry.v1 import lifecycle_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a-yandex/cloud/containerregistry/v1/image.proto\x1a\x38yandex/cloud/containerregistry/v1/lifecycle_policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"F\n\x19GetLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xe5\x01\n\x1cListLifecyclePoliciesRequest\x12\x1f\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12!\n\rrepository_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"\x88\x01\n\x1dListLifecyclePoliciesResponse\x12N\n\x12lifecycle_policies\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.containerregistry.v1.LifecyclePolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa6\x02\n\x1c\x43reateLifecyclePolicyRequest\x12#\n\rrepository_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12O\n\x06status\x18\x04 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.StatusB\x04\xe8\xc7\x31\x01\x12?\n\x05rules\x18\x05 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\"\xdd\x02\n\x1cUpdateLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12O\n\x06status\x18\x05 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.StatusB\x04\xe8\xc7\x31\x01\x12?\n\x05rules\x18\x06 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\"I\n\x1c\x44\x65leteLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x43reateLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"<\n\x1dUpdateLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"<\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"I\n\x1c\x44ryRunLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"h\n\x1d\x44ryRunLifecyclePolicyMetadata\x12*\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\t\x12\x1b\n\x13lifecycle_policy_id\x18\x02 \x01(\t\"\xb1\x01\n\x1b\x44ryRunLifecyclePolicyResult\x12*\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\t\x12\x1b\n\x13lifecycle_policy_id\x18\x02 \x01(\t\x12*\n\x06run_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15\x61\x66\x66\x65\x63ted_images_count\x18\x04 \x01(\x03\"a\n%GetDryRunLifecyclePolicyResultRequest\x12\x38\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xcb\x01\n\'ListDryRunLifecyclePolicyResultsRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xad\x01\n(ListDryRunLifecyclePolicyResultsResponse\x12h\n dry_run_lifecycle_policy_results\x18\x01 \x03(\x0b\x32>.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe7\x01\n4ListDryRunLifecyclePolicyResultAffectedImagesRequest\x12\x38\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x93\x01\n5ListDryRunLifecyclePolicyResultAffectedImagesResponse\x12\x41\n\x0f\x61\x66\x66\x65\x63ted_images\x18\x01 \x03(\x0b\x32(.yandex.cloud.containerregistry.v1.Image\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe6\x0b\n\x16LifecyclePolicyService\x12w\n\x03Get\x12<.yandex.cloud.containerregistry.v1.GetLifecyclePolicyRequest\x1a\x32.yandex.cloud.containerregistry.v1.LifecyclePolicy\x12\x89\x01\n\x04List\x12?.yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest\x1a@.yandex.cloud.containerregistry.v1.ListLifecyclePoliciesResponse\x12\xa2\x01\n\x06\x43reate\x12?.yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"4\xb2\xd2*0\n\x1d\x43reateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x12\xa2\x01\n\x06Update\x12?.yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"4\xb2\xd2*0\n\x1dUpdateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x12\xa8\x01\n\x06\x44\x65lete\x12?.yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\":\xb2\xd2*6\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x15google.protobuf.Empty\x12\xae\x01\n\x06\x44ryRun\x12?.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*<\n\x1d\x44ryRunLifecyclePolicyMetadata\x12\x1b\x44ryRunLifecyclePolicyResult\x12\x9b\x01\n\x0fGetDryRunResult\x12H.yandex.cloud.containerregistry.v1.GetDryRunLifecyclePolicyResultRequest\x1a>.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult\x12\xac\x01\n\x11ListDryRunResults\x12J.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest\x1aK.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsResponse\x12\xd3\x01\n\x1eListDryRunResultAffectedImages\x12W.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest\x1aX.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesResponseB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2.DESCRIPTOR,yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_GETLIFECYCLEPOLICYREQUEST = _descriptor.Descriptor(
  name='GetLifecyclePolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.GetLifecyclePolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.GetLifecyclePolicyRequest.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=450,
)


_LISTLIFECYCLEPOLICIESREQUEST = _descriptor.Descriptor(
  name='ListLifecyclePoliciesRequest',
  full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository_id', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest.repository_id', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest.page_size', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest.page_token', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest.filter', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest.order_by', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=453,
  serialized_end=682,
)


_LISTLIFECYCLEPOLICIESRESPONSE = _descriptor.Descriptor(
  name='ListLifecyclePoliciesResponse',
  full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policies', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesResponse.lifecycle_policies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.containerregistry.v1.ListLifecyclePoliciesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=821,
)


_CREATELIFECYCLEPOLICYREQUEST = _descriptor.Descriptor(
  name='CreateLifecyclePolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repository_id', full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest.repository_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest.rules', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=824,
  serialized_end=1118,
)


_UPDATELIFECYCLEPOLICYREQUEST = _descriptor.Descriptor(
  name='UpdateLifecyclePolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest.rules', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1470,
)


_DELETELIFECYCLEPOLICYREQUEST = _descriptor.Descriptor(
  name='DeleteLifecyclePolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyRequest.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1472,
  serialized_end=1545,
)


_CREATELIFECYCLEPOLICYMETADATA = _descriptor.Descriptor(
  name='CreateLifecyclePolicyMetadata',
  full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.CreateLifecyclePolicyMetadata.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1607,
)


_UPDATELIFECYCLEPOLICYMETADATA = _descriptor.Descriptor(
  name='UpdateLifecyclePolicyMetadata',
  full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyMetadata.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1609,
  serialized_end=1669,
)


_DELETELIFECYCLEPOLICYMETADATA = _descriptor.Descriptor(
  name='DeleteLifecyclePolicyMetadata',
  full_name='yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyMetadata.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1731,
)


_DRYRUNLIFECYCLEPOLICYREQUEST = _descriptor.Descriptor(
  name='DryRunLifecyclePolicyRequest',
  full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyRequest.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1806,
)


_DRYRUNLIFECYCLEPOLICYMETADATA = _descriptor.Descriptor(
  name='DryRunLifecyclePolicyMetadata',
  full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dry_run_lifecycle_policy_result_id', full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyMetadata.dry_run_lifecycle_policy_result_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyMetadata.lifecycle_policy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1808,
  serialized_end=1912,
)


_DRYRUNLIFECYCLEPOLICYRESULT = _descriptor.Descriptor(
  name='DryRunLifecyclePolicyResult',
  full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dry_run_lifecycle_policy_result_id', full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult.dry_run_lifecycle_policy_result_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult.lifecycle_policy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_at', full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult.run_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_images_count', full_name='yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult.affected_images_count', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1915,
  serialized_end=2092,
)


_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST = _descriptor.Descriptor(
  name='GetDryRunLifecyclePolicyResultRequest',
  full_name='yandex.cloud.containerregistry.v1.GetDryRunLifecyclePolicyResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dry_run_lifecycle_policy_result_id', full_name='yandex.cloud.containerregistry.v1.GetDryRunLifecyclePolicyResultRequest.dry_run_lifecycle_policy_result_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2094,
  serialized_end=2191,
)


_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST = _descriptor.Descriptor(
  name='ListDryRunLifecyclePolicyResultsRequest',
  full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lifecycle_policy_id', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest.lifecycle_policy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2194,
  serialized_end=2397,
)


_LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE = _descriptor.Descriptor(
  name='ListDryRunLifecyclePolicyResultsResponse',
  full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dry_run_lifecycle_policy_results', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsResponse.dry_run_lifecycle_policy_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2400,
  serialized_end=2573,
)


_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST = _descriptor.Descriptor(
  name='ListDryRunLifecyclePolicyResultAffectedImagesRequest',
  full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dry_run_lifecycle_policy_result_id', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest.dry_run_lifecycle_policy_result_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2576,
  serialized_end=2807,
)


_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE = _descriptor.Descriptor(
  name='ListDryRunLifecyclePolicyResultAffectedImagesResponse',
  full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='affected_images', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesResponse.affected_images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2810,
  serialized_end=2957,
)

_LISTLIFECYCLEPOLICIESREQUEST.oneofs_by_name['id'].fields.append(
  _LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['registry_id'])
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['registry_id'].containing_oneof = _LISTLIFECYCLEPOLICIESREQUEST.oneofs_by_name['id']
_LISTLIFECYCLEPOLICIESREQUEST.oneofs_by_name['id'].fields.append(
  _LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['repository_id'])
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['repository_id'].containing_oneof = _LISTLIFECYCLEPOLICIESREQUEST.oneofs_by_name['id']
_LISTLIFECYCLEPOLICIESRESPONSE.fields_by_name['lifecycle_policies'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2._LIFECYCLEPOLICY
_CREATELIFECYCLEPOLICYREQUEST.fields_by_name['status'].enum_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2._LIFECYCLEPOLICY_STATUS
_CREATELIFECYCLEPOLICYREQUEST.fields_by_name['rules'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2._LIFECYCLERULE
_UPDATELIFECYCLEPOLICYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATELIFECYCLEPOLICYREQUEST.fields_by_name['status'].enum_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2._LIFECYCLEPOLICY_STATUS
_UPDATELIFECYCLEPOLICYREQUEST.fields_by_name['rules'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2._LIFECYCLERULE
_DRYRUNLIFECYCLEPOLICYRESULT.fields_by_name['run_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE.fields_by_name['dry_run_lifecycle_policy_results'].message_type = _DRYRUNLIFECYCLEPOLICYRESULT
_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE.fields_by_name['affected_images'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2._IMAGE
DESCRIPTOR.message_types_by_name['GetLifecyclePolicyRequest'] = _GETLIFECYCLEPOLICYREQUEST
DESCRIPTOR.message_types_by_name['ListLifecyclePoliciesRequest'] = _LISTLIFECYCLEPOLICIESREQUEST
DESCRIPTOR.message_types_by_name['ListLifecyclePoliciesResponse'] = _LISTLIFECYCLEPOLICIESRESPONSE
DESCRIPTOR.message_types_by_name['CreateLifecyclePolicyRequest'] = _CREATELIFECYCLEPOLICYREQUEST
DESCRIPTOR.message_types_by_name['UpdateLifecyclePolicyRequest'] = _UPDATELIFECYCLEPOLICYREQUEST
DESCRIPTOR.message_types_by_name['DeleteLifecyclePolicyRequest'] = _DELETELIFECYCLEPOLICYREQUEST
DESCRIPTOR.message_types_by_name['CreateLifecyclePolicyMetadata'] = _CREATELIFECYCLEPOLICYMETADATA
DESCRIPTOR.message_types_by_name['UpdateLifecyclePolicyMetadata'] = _UPDATELIFECYCLEPOLICYMETADATA
DESCRIPTOR.message_types_by_name['DeleteLifecyclePolicyMetadata'] = _DELETELIFECYCLEPOLICYMETADATA
DESCRIPTOR.message_types_by_name['DryRunLifecyclePolicyRequest'] = _DRYRUNLIFECYCLEPOLICYREQUEST
DESCRIPTOR.message_types_by_name['DryRunLifecyclePolicyMetadata'] = _DRYRUNLIFECYCLEPOLICYMETADATA
DESCRIPTOR.message_types_by_name['DryRunLifecyclePolicyResult'] = _DRYRUNLIFECYCLEPOLICYRESULT
DESCRIPTOR.message_types_by_name['GetDryRunLifecyclePolicyResultRequest'] = _GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST
DESCRIPTOR.message_types_by_name['ListDryRunLifecyclePolicyResultsRequest'] = _LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST
DESCRIPTOR.message_types_by_name['ListDryRunLifecyclePolicyResultsResponse'] = _LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['ListDryRunLifecyclePolicyResultAffectedImagesRequest'] = _LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST
DESCRIPTOR.message_types_by_name['ListDryRunLifecyclePolicyResultAffectedImagesResponse'] = _LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLifecyclePolicyRequest = _reflection.GeneratedProtocolMessageType('GetLifecyclePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLIFECYCLEPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.GetLifecyclePolicyRequest)
  })
_sym_db.RegisterMessage(GetLifecyclePolicyRequest)

ListLifecyclePoliciesRequest = _reflection.GeneratedProtocolMessageType('ListLifecyclePoliciesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLIFECYCLEPOLICIESREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest)
  })
_sym_db.RegisterMessage(ListLifecyclePoliciesRequest)

ListLifecyclePoliciesResponse = _reflection.GeneratedProtocolMessageType('ListLifecyclePoliciesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLIFECYCLEPOLICIESRESPONSE,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListLifecyclePoliciesResponse)
  })
_sym_db.RegisterMessage(ListLifecyclePoliciesResponse)

CreateLifecyclePolicyRequest = _reflection.GeneratedProtocolMessageType('CreateLifecyclePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELIFECYCLEPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest)
  })
_sym_db.RegisterMessage(CreateLifecyclePolicyRequest)

UpdateLifecyclePolicyRequest = _reflection.GeneratedProtocolMessageType('UpdateLifecyclePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELIFECYCLEPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest)
  })
_sym_db.RegisterMessage(UpdateLifecyclePolicyRequest)

DeleteLifecyclePolicyRequest = _reflection.GeneratedProtocolMessageType('DeleteLifecyclePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELIFECYCLEPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyRequest)
  })
_sym_db.RegisterMessage(DeleteLifecyclePolicyRequest)

CreateLifecyclePolicyMetadata = _reflection.GeneratedProtocolMessageType('CreateLifecyclePolicyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATELIFECYCLEPOLICYMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.CreateLifecyclePolicyMetadata)
  })
_sym_db.RegisterMessage(CreateLifecyclePolicyMetadata)

UpdateLifecyclePolicyMetadata = _reflection.GeneratedProtocolMessageType('UpdateLifecyclePolicyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELIFECYCLEPOLICYMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyMetadata)
  })
_sym_db.RegisterMessage(UpdateLifecyclePolicyMetadata)

DeleteLifecyclePolicyMetadata = _reflection.GeneratedProtocolMessageType('DeleteLifecyclePolicyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETELIFECYCLEPOLICYMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyMetadata)
  })
_sym_db.RegisterMessage(DeleteLifecyclePolicyMetadata)

DryRunLifecyclePolicyRequest = _reflection.GeneratedProtocolMessageType('DryRunLifecyclePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DRYRUNLIFECYCLEPOLICYREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyRequest)
  })
_sym_db.RegisterMessage(DryRunLifecyclePolicyRequest)

DryRunLifecyclePolicyMetadata = _reflection.GeneratedProtocolMessageType('DryRunLifecyclePolicyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DRYRUNLIFECYCLEPOLICYMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyMetadata)
  })
_sym_db.RegisterMessage(DryRunLifecyclePolicyMetadata)

DryRunLifecyclePolicyResult = _reflection.GeneratedProtocolMessageType('DryRunLifecyclePolicyResult', (_message.Message,), {
  'DESCRIPTOR' : _DRYRUNLIFECYCLEPOLICYRESULT,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult)
  })
_sym_db.RegisterMessage(DryRunLifecyclePolicyResult)

GetDryRunLifecyclePolicyResultRequest = _reflection.GeneratedProtocolMessageType('GetDryRunLifecyclePolicyResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.GetDryRunLifecyclePolicyResultRequest)
  })
_sym_db.RegisterMessage(GetDryRunLifecyclePolicyResultRequest)

ListDryRunLifecyclePolicyResultsRequest = _reflection.GeneratedProtocolMessageType('ListDryRunLifecyclePolicyResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest)
  })
_sym_db.RegisterMessage(ListDryRunLifecyclePolicyResultsRequest)

ListDryRunLifecyclePolicyResultsResponse = _reflection.GeneratedProtocolMessageType('ListDryRunLifecyclePolicyResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsResponse)
  })
_sym_db.RegisterMessage(ListDryRunLifecyclePolicyResultsResponse)

ListDryRunLifecyclePolicyResultAffectedImagesRequest = _reflection.GeneratedProtocolMessageType('ListDryRunLifecyclePolicyResultAffectedImagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest)
  })
_sym_db.RegisterMessage(ListDryRunLifecyclePolicyResultAffectedImagesRequest)

ListDryRunLifecyclePolicyResultAffectedImagesResponse = _reflection.GeneratedProtocolMessageType('ListDryRunLifecyclePolicyResultAffectedImagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE,
  '__module__' : 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesResponse)
  })
_sym_db.RegisterMessage(ListDryRunLifecyclePolicyResultAffectedImagesResponse)


DESCRIPTOR._options = None
_GETLIFECYCLEPOLICYREQUEST.fields_by_name['lifecycle_policy_id']._options = None
_LISTLIFECYCLEPOLICIESREQUEST.oneofs_by_name['id']._options = None
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['registry_id']._options = None
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['repository_id']._options = None
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['page_size']._options = None
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['page_token']._options = None
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['filter']._options = None
_LISTLIFECYCLEPOLICIESREQUEST.fields_by_name['order_by']._options = None
_CREATELIFECYCLEPOLICYREQUEST.fields_by_name['repository_id']._options = None
_CREATELIFECYCLEPOLICYREQUEST.fields_by_name['name']._options = None
_CREATELIFECYCLEPOLICYREQUEST.fields_by_name['description']._options = None
_CREATELIFECYCLEPOLICYREQUEST.fields_by_name['status']._options = None
_UPDATELIFECYCLEPOLICYREQUEST.fields_by_name['lifecycle_policy_id']._options = None
_UPDATELIFECYCLEPOLICYREQUEST.fields_by_name['name']._options = None
_UPDATELIFECYCLEPOLICYREQUEST.fields_by_name['description']._options = None
_UPDATELIFECYCLEPOLICYREQUEST.fields_by_name['status']._options = None
_DELETELIFECYCLEPOLICYREQUEST.fields_by_name['lifecycle_policy_id']._options = None
_DRYRUNLIFECYCLEPOLICYREQUEST.fields_by_name['lifecycle_policy_id']._options = None
_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST.fields_by_name['dry_run_lifecycle_policy_result_id']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST.fields_by_name['lifecycle_policy_id']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST.fields_by_name['page_size']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST.fields_by_name['page_token']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST.fields_by_name['filter']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST.fields_by_name['order_by']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST.fields_by_name['dry_run_lifecycle_policy_result_id']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST.fields_by_name['page_size']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST.fields_by_name['page_token']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST.fields_by_name['filter']._options = None
_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST.fields_by_name['order_by']._options = None

_LIFECYCLEPOLICYSERVICE = _descriptor.ServiceDescriptor(
  name='LifecyclePolicyService',
  full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2960,
  serialized_end=4470,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.Get',
    index=0,
    containing_service=None,
    input_type=_GETLIFECYCLEPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2._LIFECYCLEPOLICY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.List',
    index=1,
    containing_service=None,
    input_type=_LISTLIFECYCLEPOLICIESREQUEST,
    output_type=_LISTLIFECYCLEPOLICIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATELIFECYCLEPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*0\n\035CreateLifecyclePolicyMetadata\022\017LifecyclePolicy',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATELIFECYCLEPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*0\n\035UpdateLifecyclePolicyMetadata\022\017LifecyclePolicy',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETELIFECYCLEPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*6\n\035DeleteLifecyclePolicyMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DryRun',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.DryRun',
    index=5,
    containing_service=None,
    input_type=_DRYRUNLIFECYCLEPOLICYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*<\n\035DryRunLifecyclePolicyMetadata\022\033DryRunLifecyclePolicyResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDryRunResult',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.GetDryRunResult',
    index=6,
    containing_service=None,
    input_type=_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST,
    output_type=_DRYRUNLIFECYCLEPOLICYRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDryRunResults',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.ListDryRunResults',
    index=7,
    containing_service=None,
    input_type=_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST,
    output_type=_LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDryRunResultAffectedImages',
    full_name='yandex.cloud.containerregistry.v1.LifecyclePolicyService.ListDryRunResultAffectedImages',
    index=8,
    containing_service=None,
    input_type=_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST,
    output_type=_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LIFECYCLEPOLICYSERVICE)

DESCRIPTOR.services_by_name['LifecyclePolicyService'] = _LIFECYCLEPOLICYSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.apploadbalancer.v1 import load_balancer_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2
from yandex.cloud.apploadbalancer.v1 import load_balancer_service_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class LoadBalancerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Get',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2.LoadBalancer.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/List',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Create',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.CreateLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Update',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Delete',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.DeleteLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Start = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Start',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StartLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Stop = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Stop',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StopLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AddListener = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddListener',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveListener = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveListener',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateListener = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateListener',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AddSniMatch = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddSniMatch',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddSniMatchRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateSniMatch = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateSniMatch',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateSniMatchRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveSniMatch = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveSniMatch',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveSniMatchRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetTargetStates = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/GetTargetStates',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesResponse.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsResponse.FromString,
                )


class LoadBalancerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddListener(self, request, context):
        """AddListener/UpdateListener technically do the same, but have different semantics.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveListener(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateListener(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddSniMatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSniMatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveSniMatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTargetStates(self, request, context):
        """Returns zonal state of each target within target group
        for a given backend group and load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LoadBalancerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2.LoadBalancer.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.CreateLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.DeleteLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StartLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StopLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddListener': grpc.unary_unary_rpc_method_handler(
                    servicer.AddListener,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveListener': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveListener,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateListener': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateListener,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddSniMatch': grpc.unary_unary_rpc_method_handler(
                    servicer.AddSniMatch,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddSniMatchRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateSniMatch': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSniMatch,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateSniMatchRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveSniMatch': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveSniMatch,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveSniMatchRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetTargetStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTargetStates,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesResponse.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.apploadbalancer.v1.LoadBalancerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LoadBalancerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Get',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2.LoadBalancer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/List',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Create',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.CreateLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Update',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Delete',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.DeleteLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Start',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StartLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Stop',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StopLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddListener',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveListener',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateListener',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddSniMatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddSniMatch',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddSniMatchRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSniMatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateSniMatch',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateSniMatchRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveSniMatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveSniMatch',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveSniMatchRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTargetStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/GetTargetStates',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/ListOperations',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
